==> vtk-6.3.0-5-armv7h.pkg.tar.xz: vtk/vtkImageSlice.java <==
// java wrapper for vtkImageSlice object
//

package vtk;
import vtk.*;

public class vtkImageSlice extends vtkProp3D
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetMapper_2(vtkImageMapper3D id0);
  public void SetMapper(vtkImageMapper3D id0)
    { SetMapper_2(id0); }

  private native long GetMapper_3();
  public vtkImageMapper3D GetMapper() {
    long temp = GetMapper_3();

    if (temp == 0) return null;
    return (vtkImageMapper3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetProperty_4(vtkImageProperty id0);
  public void SetProperty(vtkImageProperty id0)
    { SetProperty_4(id0); }

  private native long GetProperty_5();
  public vtkImageProperty GetProperty() {
    long temp = GetProperty_5();

    if (temp == 0) return null;
    return (vtkImageProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void Update_6();
  public void Update()
    { Update_6(); }

  private native void GetBounds_7(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_7(id0); }

  private native double GetMinXBound_8();
  public double GetMinXBound()
    { return GetMinXBound_8(); }

  private native double GetMaxXBound_9();
  public double GetMaxXBound()
    { return GetMaxXBound_9(); }

  private native double GetMinYBound_10();
  public double GetMinYBound()
    { return GetMinYBound_10(); }

  private native double GetMaxYBound_11();
  public double GetMaxYBound()
    { return GetMaxYBound_11(); }

  private native double GetMinZBound_12();
  public double GetMinZBound()
    { return GetMinZBound_12(); }

  private native double GetMaxZBound_13();
  public double GetMaxZBound()
    { return GetMaxZBound_13(); }

  private native int GetMTime_14();
  public int GetMTime()
    { return GetMTime_14(); }

  private native int GetRedrawMTime_15();
  public int GetRedrawMTime()
    { return GetRedrawMTime_15(); }

  private native void ShallowCopy_16(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_16(id0); }

  private native void GetImages_17(vtkPropCollection id0);
  public void GetImages(vtkPropCollection id0)
    { GetImages_17(id0); }

  private native int RenderOverlay_18(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_18(id0); }

  private native int RenderOpaqueGeometry_19(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_19(id0); }

  private native int RenderTranslucentPolygonalGeometry_20(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_20(id0); }

  private native int HasTranslucentPolygonalGeometry_21();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_21(); }

  private native void Render_22(vtkRenderer id0);
  public void Render(vtkRenderer id0)
    { Render_22(id0); }

  private native void ReleaseGraphicsResources_23(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_23(id0); }

  private native void SetStackedImagePass_24(int id0);
  public void SetStackedImagePass(int id0)
    { SetStackedImagePass_24(id0); }

  public vtkImageSlice() { super(); }

  public vtkImageSlice(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkImageSlice.java <==
// java wrapper for vtkImageSlice object
//

package vtk;
import vtk.*;

public class vtkImageSlice extends vtkProp3D
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetMapper_2(vtkImageMapper3D id0);
  public void SetMapper(vtkImageMapper3D id0)
    { SetMapper_2(id0); }

  private native long GetMapper_3();
  public vtkImageMapper3D GetMapper() {
    long temp = GetMapper_3();

    if (temp == 0) return null;
    return (vtkImageMapper3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetProperty_4(vtkImageProperty id0);
  public void SetProperty(vtkImageProperty id0)
    { SetProperty_4(id0); }

  private native long GetProperty_5();
  public vtkImageProperty GetProperty() {
    long temp = GetProperty_5();

    if (temp == 0) return null;
    return (vtkImageProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void Update_6();
  public void Update()
    { Update_6(); }

  private native void GetBounds_7(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_7(id0); }

  private native double GetMinXBound_8();
  public double GetMinXBound()
    { return GetMinXBound_8(); }

  private native double GetMaxXBound_9();
  public double GetMaxXBound()
    { return GetMaxXBound_9(); }

  private native double GetMinYBound_10();
  public double GetMinYBound()
    { return GetMinYBound_10(); }

  private native double GetMaxYBound_11();
  public double GetMaxYBound()
    { return GetMaxYBound_11(); }

  private native double GetMinZBound_12();
  public double GetMinZBound()
    { return GetMinZBound_12(); }

  private native double GetMaxZBound_13();
  public double GetMaxZBound()
    { return GetMaxZBound_13(); }

  private native int GetMTime_14();
  public int GetMTime()
    { return GetMTime_14(); }

  private native int GetRedrawMTime_15();
  public int GetRedrawMTime()
    { return GetRedrawMTime_15(); }

  private native boolean GetForceTranslucent_16();
  public boolean GetForceTranslucent()
    { return GetForceTranslucent_16(); }

  private native void SetForceTranslucent_17(boolean id0);
  public void SetForceTranslucent(boolean id0)
    { SetForceTranslucent_17(id0); }

  private native void ForceTranslucentOn_18();
  public void ForceTranslucentOn()
    { ForceTranslucentOn_18(); }

  private native void ForceTranslucentOff_19();
  public void ForceTranslucentOff()
    { ForceTranslucentOff_19(); }

  private native void ShallowCopy_20(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_20(id0); }

  private native void GetImages_21(vtkPropCollection id0);
  public void GetImages(vtkPropCollection id0)
    { GetImages_21(id0); }

  private native int RenderOverlay_22(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_22(id0); }

  private native int RenderOpaqueGeometry_23(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_23(id0); }

  private native int RenderTranslucentPolygonalGeometry_24(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_24(id0); }

  private native int HasTranslucentPolygonalGeometry_25();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_25(); }

  private native void Render_26(vtkRenderer id0);
  public void Render(vtkRenderer id0)
    { Render_26(id0); }

  private native void ReleaseGraphicsResources_27(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_27(id0); }

  private native void SetStackedImagePass_28(int id0);
  public void SetStackedImagePass(int id0)
    { SetStackedImagePass_28(id0); }

  public vtkImageSlice() { super(); }

  public vtkImageSlice(long id) { super(id); }
  public native long   VTKInit();

}
